/*
 * FILE:   display.h
 * AUTHOR: Colin Perkins <csp@isi.edu>
 *
 * Copyright (c) 2001-2002 University of Southern California
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 * 
 *      This product includes software developed by the University of Southern
 *      California Information Sciences Institute.
 * 
 * 4. Neither the name of the University nor of the Institute may be used
 *    to endorse or promote products derived from this software without
 *    specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Revision: 1.4 $
 * $Date: 2002/08/27 21:48:17 $
 *
 */

/*
 * Interface to probing the valid display types. 
 *
 */

typedef uint32_t	display_id_t;

struct display_type {
	display_id_t	 id;
	const char	*name;		/* Single word name. */
	const char	*description;
	unsigned int	 width;
	unsigned int	 height;
	unsigned int	 max_images;	/* Number of simultaneous images that can be displayed; 0 = unlimited */
};

void			 display_init_devices(void);
void			 display_free_devices(void);
int			 display_get_device_count(void);
struct display_type	*display_get_device_details(int index);
display_id_t 		 display_get_null_device_id(void);

/* 
 * Interface to initialize displays, and playout video
 *
 */

struct display;

typedef enum {
	DC_YUV,
	DC_RGB,
	DC_NULL,
} display_colour_t;

struct display	*display_init(display_id_t id);
void 		 display_done(struct display *d);
char		*display_get_frame(struct display *d);
void 		 display_put_frame(struct display *d, char *frame);
display_colour_t display_get_colour_mode(struct display *d);

