/*
 * FILE:   test_tfrc.c
 * AUTHOR: Colin Perkins <csp@isi.edu>
 *
 * Copyright (c) 2002 University of Southern California
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 * 
 *      This product includes software developed by the University of Southern
 *      California Information Sciences Institute.
 * 
 * 4. Neither the name of the University nor of the Institute may be used
 *    to endorse or promote products derived from this software without
 *    specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Revision: 1.3 $
 * $Date: 2002/10/08 15:08:15 $
 *
 */

#include "config.h"
#include "config_unix.h"
#include "config_win32.h"
#include "debug.h"
#include "tfrc.h"

#ifdef NDEF
static struct timeval
TIME(double time)
{
	FIXME
}
#endif


static void
test_tfrc_basic(void)
{
#ifdef NDEF
	struct tfrc *state;

	state = tfrc_init(TIME(0.0));

	tfrc_recv_rtt(state, TIME(0.0), 100000);	/* 100ms RTT */
	tfrc_recv_data(state, TIME(...), seq, len);
	...

	if (tfrc_feedback_txrate(state, ...) != ...) {
		printf("Testing TFRC basic behaviour ............................................. FAIL\n");
	} else {
		printf("Testing TFRC basic behaviour ............................................. PASS\n");
	}
	tfrc_done(state);
#endif
}

static void
test_tfrc_loss_event(void)
{
	//printf("Testing TFRC loss event rate vs loss rate ................................ FAIL\n");
}

static void
test_tfrc_psize(void)
{
	//printf("Testing TFRC response to changed packet size ............................. FAIL\n");
}

static void
test_tfrc_rtt(void)
{
	//printf("Testing TFRC response to changed RTT ..................................... FAIL\n");
}

static void
test_tfrc_feedback_interval(void)
{
	//printf("Testing TFRC feedback interval ........................................... FAIL\n");
}

int
main(int argc, char *argv[])
{
	/* Test plan:
	 *	1) Basic behaviour: send with lost packets > 1 RTT apart
	 *	2) Loss event vs lost packet: as above, but with multiple loss per RTT. Should give
	 *         the same rate as test 1.
	 *	3) Halve packet size, watch throughput halve
	 *	4) Halve RTT, throughput should approximately double (it will actually more than 
	 *         double, because of the t_RTO = 4*R term).
	 *	5) Check feedback intervals
	 */
	UNUSED(argc);
	UNUSED(argv);

	test_tfrc_basic();
	test_tfrc_loss_event();
	test_tfrc_psize();
	test_tfrc_rtt();
	test_tfrc_feedback_interval();

	return 0;
}

